@@ -161,7 +161,7 @@ void update_blocked_widget(GtkWidget *w, gboolean sens) {
 /* Concats @base_dir and @rel_dir if and only if @rel_dir is not
  * absolute (does not start with '~' or '/'). Otherwise simply return
  * a copy of @rel_dir. Must free return value after use */
-gchar *concat_dir_if_relative(G_CONST_RETURN gchar *base_dir, G_CONST_RETURN gchar *rel_dir) {
+gchar *concat_dir_if_relative(const gchar *base_dir, const gchar *rel_dir) {
     /* sanity */
     if (!rel_dir || !*rel_dir)
         return g_build_filename(base_dir, rel_dir, NULL);
@@ -280,7 +280,7 @@ static void do_script(const gchar *script, va_list args) {
     argv = (char **) g_ptr_array_free(ptra, FALSE);
 
     if (script) {
-        pid_t pid, tpid;
+        pid_t pid;
         int status;
 
         pid = fork();
@@ -292,7 +292,7 @@ static void do_script(const gchar *script, va_list args) {
         case -1: /* parent and error */
             break;
         default: /* parent -- let's wait for the child to terminate */
-            tpid = waitpid(pid, &status, 0);
+            waitpid(pid, &status, 0);
             /* we could evaluate tpid and status now */
             break;
         }
