@@ -43,12 +43,6 @@
 #include "details.h"
 #include "fetchcover.h"
 
-#ifndef HAVE_GSEALED_GDK
-/* Compatibility macros for previous GDK versions */
-#define gdk_drag_context_get_selected_action(x) ((x)->action)
-#define gdk_drag_context_get_suggested_action(x) ((x)->suggested_action)
-#endif
-
 /* string constants for preferences */
 const gchar *DETAILS_WINDOW_NOTEBOOK_PAGE = "details_window_notebook_page";
 
@@ -896,7 +890,6 @@ static void details_get_item(T_item item, gboolean assumechanged) {
     case T_TITLE:
     case T_GENRE:
     case T_COMPOSER:
-    case T_FILETYPE:
     case T_GROUPING:
     case T_CATEGORY:
     case T_PODCASTURL:
@@ -1081,6 +1074,7 @@ static void details_get_item(T_item item, gboolean assumechanged) {
             }
         }
         break;
+    case T_FILETYPE:
     case T_TRANSFERRED:
     case T_PC_PATH:
     case T_IPOD_PATH:
@@ -1089,7 +1083,6 @@ static void details_get_item(T_item item, gboolean assumechanged) {
     case T_GAPLESS_TRACK_FLAG:
         /* These are read-only only */
         break;
-        break;
     case T_ALL:
     case T_ITEM_NUM:
         /* cannot happen because of assertion above */
