@@ -49,12 +49,6 @@
 #include "libgtkpod/gtkpod_app_iface.h"
 #include "libgtkpod/prefs.h"
 
-#ifndef HAVE_GSEALED_GDK
-/* Compatibility macros for previous GDK versions */
-#define gdk_drag_context_get_selected_action(x) ((x)->action)
-#define gdk_drag_context_get_suggested_action(x) ((x)->suggested_action)
-#endif
-
 /* pointer to the playlist display's toolbar */
 static GtkToolbar *playlist_toolbar = NULL;
 /* pointer to the treeview for the playlist display */
@@ -834,7 +828,7 @@ static gboolean on_playlist_treeview_key_release_event(GtkWidget *widget, GdkEve
         /* 	    case GDK_u: */
         /* 		gp_do_selected_playlist (update_tracks); */
         /* 		break; */
-        case GDK_n:
+        case GDK_KEY_N:
             if (itdb) {
                 add_new_pl_or_spl_user_name(itdb, NULL, -1);
             }
@@ -1992,7 +1986,7 @@ GtkWidget *pm_create_playlist_view(GtkActionGroup *action_group) {
     GtkBox *vbox;
     GtkScrolledWindow *scrolledwin;
 
-    vbox = GTK_BOX(gtk_vbox_new (FALSE, 0));
+    vbox = GTK_BOX(gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
 
     pm_create_toolbar(action_group);
     gtk_box_pack_start(vbox, GTK_WIDGET(playlist_toolbar), FALSE, TRUE, 0);
