@@ -52,12 +52,6 @@
 #include "rb_cell_renderer_rating.h"
 #include "track_display_context_menu.h"
 
-#ifndef HAVE_GSEALED_GDK
-/* Compatibility macros for previous GDK versions */
-#define gdk_drag_context_get_selected_action(x) ((x)->action)
-#define gdk_drag_context_get_suggested_action(x) ((x)->suggested_action)
-#endif
-
 /* reference to gtkbuilder for use with track plugin */
 static GtkBuilder *trackbuilder = NULL;
 /* pointer to the container for the track display */
@@ -1823,8 +1817,6 @@ static GtkTreeViewColumn *tm_add_column(TM_item tm_item, gint pos) {
         /* for some column names we want to use shorter alternatives to
          get_tm_string() */
     case TM_COLUMN_RATING:
-        gtk_tree_view_column_set_fixed_width(col, 85);
-        gtk_tree_view_column_set_resizable(col, FALSE);
         text = _("Rating");
         break;
     case TM_COLUMN_TRACK_NR:
@@ -2147,8 +2139,15 @@ void tm_show_preferred_columns(void) {
             col_width = 80;
 
         if (horizontal_scrollbar) {
-            gtk_tree_view_column_set_fixed_width(tvc, col_width);
-            gtk_tree_view_column_set_min_width(tvc, -1);
+            switch(tm_item) {
+            case TM_COLUMN_RATING:
+                gtk_tree_view_column_set_fixed_width(tvc, 85);
+                gtk_tree_view_column_set_min_width(tvc, 85);
+                break;
+            default:
+                gtk_tree_view_column_set_fixed_width(tvc, col_width);
+                gtk_tree_view_column_set_min_width(tvc, -1);
+            }
             gtk_tree_view_column_set_expand(tvc, FALSE);
         }
         else {
